@@ -3,7 +3,7 @@
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
 #' @export
-bash <- function(pkg = NULL) {
+bash <- function(pkg = ".") {
   pkg <- as.package(pkg)
   
   in_dir(pkg$path, system("bash"))
