@@ -5,8 +5,9 @@
 #'
 #' @param project Gitorious project name
 #' @param repo Repo name
-#' @param branch Desired branch - defaults to \code{"master"}
+#' @param ref Desired git ref - defaults to \code{"master"}
 #' @param subdir subdirectory within repo that contains the R package.
+#' @param branch Deprecated. Use \code{ref} instead.
 #' @param ... Other arguments passed on to \code{\link{install}}.
 #' @export
 #' @family package installation
@@ -14,7 +15,13 @@
 #' \dontrun{
 #' install_gitorious("r-mpc-package")
 #' }
-install_gitorious <- function(repo, project = repo, branch = "master", subdir = NULL, ...) {
+install_gitorious <- function(repo, project = repo, ref = "master",
+  subdir = NULL, branch = NULL, ...) {
+
+  if (!is.null(branch)) {
+    warning("'branch' is deprecated. In the future, please use 'ref' instead.")
+    ref <- branch
+  }
   message("Installing gitorious repo(s) ", 
     paste(repo, collapse = ", "), 
     " from ", 
@@ -24,7 +31,7 @@ install_gitorious <- function(repo, project = repo, branch = "master", subdir =
   project <- tolower(project)  
 
   url <- paste("https://gitorious.org/", project, "/", repo,
-    "/archive-tarball/", branch, sep = "")
+    "/archive-tarball/", ref, sep = "")
     
   install_url(url, paste(repo, ".tar.gz", sep = ""), subdir = subdir, ...)
 }
